@@ -18,7 +18,6 @@
 ;; Keywords: git tools vc
 
 ;; Package-Version: 4.4.2
-;; Package-Revision: v4.4.2-0-gb828afbb4b45
 ;; Package-Requires: (
 ;;     (emacs        "28.1")
 ;;     (compat       "30.1")
@@ -325,7 +324,7 @@ already been run."
 
 ;;; Dispatch Popup
 
-;;;###autoload (autoload 'magit-dispatch "magit" nil t)
+;;;###autoload(autoload 'magit-dispatch "magit" nil t)
 (transient-define-prefix magit-dispatch ()
   "Invoke a Magit command from a list of available commands."
   :info-manual "(magit)Top"
@@ -416,7 +415,7 @@ This affects `magit-git-command', `magit-git-command-topdir',
 
 (defvar magit-git-command-history nil)
 
-;;;###autoload (autoload 'magit-run "magit" nil t)
+;;;###autoload(autoload 'magit-run "magit" nil t)
 (transient-define-prefix magit-run ()
   "Run git or another command, or launch a graphical utility."
   [["Run git subcommand"
@@ -774,7 +773,11 @@ For X11 something like ~/.xinitrc should work.\n"
   (require 'magit-stash)
   (require 'magit-blame)
   (require 'magit-submodule)
-  (unless (load "magit-autoloads" t t)
+  ;; The `provide' form may be missing so we have to
+  ;; try harder to ensure this is loaded exactly once.
+  (unless (or (featurep 'magit-autoloads)
+              (autoloadp (symbol-function 'magit-patch))
+              (load "magit-autoloads" t))
     (require 'magit-patch)
     (require 'magit-subtree)
     (require 'magit-ediff)
